︠dbb68a0b-457e-40cc-9915-6becd7025e8f︠
from psage.eulerprod import LSeriesEllipticCurve, LSeriesTwist
︡a3eedb0b-e701-4e8a-92bf-477859ce2936︡{"done":true}︡
︠68408901-50f2-4c08-8cab-2e8bb40d9ac0s︠
def rep(alpha, primes):
    vals = []
    for p in primes:
        vals += [p.ideallog(alpha)[0]]
    return vals

def _iter__OK_mod_p(OK,P):
    M = P.pari_hnf().sage().diagonal()
    from itertools import product
    reps = product(*map(range,M))
    B = OK.basis()
    return [sum(i*j for i,j in zip(r,B)) for r in reps]


def totally_positive_generator(p):
    K = p.ring()
    units = K.unit_group().gens()
    x = p.gens_reduced()
    assert len(x)==1, "p not pricipally generated!"
    x = x[0]
    M = Matrix(GF(2),[[phi(g)<0 for phi in K.real_embeddings()] for g in units])
    v = vector(GF(2),[phi(x)<0 for phi in K.real_embeddings()])
    x *= prod(g for g,e in zip(units,M.solve_left(v)) if e)
    assert x.is_totally_positive(), "Totally positive generator does not exist!"
    return x

class NFChar():
    def __init__(self, factored_conductor, rootlist, order, zeta = None, prec = None):
        """
        Currently we allow only tamely ramified characters.
        """
        assert all(p.is_prime() for p in factored_conductor), "factored_conductor contains an element that is not prime"
        assert len(set(factored_conductor)) == len(factored_conductor), "factored_conductor contains duplicate elements"
        self._factored_conductor = factored_conductor
        self._primes_conductor = [p.smallest_integer() for p in factored_conductor]
        self._conductor = prod(factored_conductor)
        self._m = totally_positive_generator(self._conductor)
        self._rootlist = rootlist
        assert gcd(rootlist+[d])==1, "the order of the character is not %s"%(order)
        self._order = order
        self._field = factored_conductor[0].number_field()
        self._ring = self._field.maximal_order()
        self._degree = self._field.absolute_degree()
        if prec == None:
            self._CC = CC
        else:
            self._CC = ComplexField(prec)
        if zeta is None:
            self._zeta = self._CC.zeta(d)
        else:
            #assert zeta**d==1
            self._zeta = zeta
            
        assert self._field.class_number()==1
        
        for g in self._field.unit_group().gens():
            assert self._call_nf_elt(self._field(g)) == 1, " character is not 1 on units"

    def __call__(self, p):
        x = p.gens_reduced()
        assert len(x)==1, "Do not know how to evaluate on a non principal ideal!"
        return self._call_nf_elt(p.gens_reduced()[0])

    @cached_method
    def _iter_rep_mod_m(self):
        return _iter__OK_mod_p(self._ring,self._conductor)
    

    
    def gauss_sum(self):
        assert self._ring.discriminant()==5, "only implemented for sqrt5"
        tau = 0
        sqrt5 = (self._field*5).factor()[0][0].gens_reduced()[0]
        print sqrt5
        for alpha in self._iter_rep_mod_m():
            #print tau
            a = alpha/self._m#*sqrt5
            a = a.trace()
            den = a.denominator()
            num = a.numerator()
            tau += self._call_nf_elt(alpha)*self._CC.zeta(den)^(num%den)
        return tau

    def _call_nf_elt(self,alpha):
        fact = self._factored_conductor
        rootlist = self._rootlist

        for p,q in zip(self._primes_conductor,fact):
            if p.divides(alpha.norm()) and alpha in q:
                return 0
        #return m.ideallog(p.gens_reduced()[0])
        reps = rep(alpha, fact)
        #print "#rootlist %s, #reps %s"%(len(rootlist),len(reps))
        return self._zeta**(sum([rootlist[i]*reps[i] for i in range(len(rootlist))]) % self._order)


    
    def is_primitive(self):
        return all(i%self._order != 0 for i in self._rootlist)

    def conductor(self):
        return prod(self._factored_conductor).norm()

    def order(self):
        return self._order
︡d0b00a4e-4b64-42e2-bf0f-b1b1070f9437︡{"done":true}︡
︠1cc6e23a-adc6-4c32-820a-bf2af957c340︠

︡0a8a4c14-336a-459d-b95e-11c6dfac55ea︡{"done":true}︡
︠f3b0d911-7fd4-4f44-ab7f-fba1225f6b8ds︠
R.<x> = QQ[]
K.<phi>=NumberField(x^2 -x-1)
E = EllipticCurve(K, [1, phi + 1, phi, phi, 0])
m = K*13
fact = [prime for (prime, i) in m.factor()]
d = 3

︡316d4ebe-4cb5-4164-84ab-221dac7de19d︡{"done":true}︡
︠b4cd131d-be4e-45dd-8a74-ea2ef4ed4ab3s︠
foundlist = len(fact)*[1]
for t in Integers(d)^len(m.factor()):
    try:
        if 0 in list(t):
            continue
        rootlist = list(t.lift())
        chi = NFChar(fact,rootlist,d,prec=1000)
        foundlist = rootlist

        print rootlist
        x = chi.gauss_sum();
        print
        print x.abs(),x
    except:
        pass
︡c1a3f715-79e7-46a6-9ad4-05cb75216dd5︡{"stdout":"[1]\n-2*phi + 1\n\n13.0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000 11.3407561726636152699368162869855117983731253191903113812827727652124965276757522368493039894057371978570715000611418213033343214441382821742420971004022136131129716550720474800350052564067483123669351089814797540077428600188606608171977226854509076353420967694562397343116132495426591104271695619234 + 6.35509633539823757082843897576929635164123227418046373191723445222979581773290744537857331917542382091652147604151185486267441580032280296429497772415175454074114827575353571701097120106343964546518212091823462667259056273414807931764641831386718012747116711234367738464348211389670063607384427700001*I\n[2]\n-2*phi + 1\n\n"}︡{"stdout":"13.0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000 11.3407561726636152699368162869855117983731253191903113812827727652124965276757522368493039894057371978570715000611418213033343214441382821742420971004022136131129716550720474800350052564067483123669351089814797540077428600188606608171977226854509076353420967694562397343116132495426591104271695619234 - 6.35509633539823757082843897576929635164123227418046373191723445222979581773290744537857331917542382091652147604151185486267441580032280296429497772415175454074114827575353571701097120106343964546518212091823462667259056273414807931764641831386718012747116711234367738464348211389670063607384427700001*I\n"}︡{"done":true}︡
︠1cf35dc7-514f-4d64-9147-ad82816a894fs︠
x
︡b08231ee-1194-4c6d-8a5b-5bd182a8ea16︡{"stdout":"11.3407561726636152699368162869855117983731253191903113812827727652124965276757522368493039894057371978570715000611418213033343214441382821742420971004022136131129716550720474800350052564067483123669351089814797540077428600188606608171977226854509076353420967694562397343116132495426591104271695619234 - 6.35509633539823757082843897576929635164123227418046373191723445222979581773290744537857331917542382091652147604151185486267441580032280296429497772415175454074114827575353571701097120106343964546518212091823462667259056273414807931764641831386718012747116711234367738464348211389670063607384427700001*I\n"}︡{"done":true}︡
︠b2d7654f-44d3-453f-8197-46cace7319ees︠
CC1 = ComplexField(1000)
I = CC1.0
omega = prod([E.period_lattice(phi).basis(prec=1000)[0] for phi in K.embeddings(RR)])
︡3e35e6dc-e7f6-4598-a367-bee6465c1173︡{"done":true}︡
︠1ab0ba14-69a4-49fa-91b3-d2b0587fc185︠
#magma LValues for cubic twist of conductor 13 prec e-74

l1,l2 =[ 1.5457956238192788683557199097437729233665818071610358735968195553567568888501269808125460910379551385036304017986579868697753000481659891333945500875045540441514902685477548634003391025711156928736075 -
0.86622796175514932234718383126453984183577137642394022731205644771173084410073936907261536775497232496651092083801009064197224548531397645425498120806474732224747486052910601468664988353184945233634762*I,
1.5457956238192788683557199097437729233665818071610358735968195553567568888501269808125460910379551385036304017986579868697753000481659891333945500875045540441514902685477548634003391025711156928736077 +
0.86622796175514932234718383126453984183577137642394022731205644771173084410073936907261536775497232496651092083801009064197224548531397645425498120806474732224747486052910601468664988353184945233634753*I ]
︡9d928326-330b-4405-a503-3e977c84ed34︡{"stdout":"13.0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000\n"}︡{"done":true}︡
︠e26203b2-6f11-4138-81b3-683ddf067105︠

︡6af787cd-c759-48eb-9a1f-d496037a5961︡
︠1a5d1eaa-cece-4252-86ef-b55d13fb7b0es︠
#mamgma LValues for cubic twist of conductor 47 prec e74
l1,l2 = [
0.24505801487087417016068854563803448172521943510270968636805221995783706098457669244070126558322132754114006237893747704077409789994033154666761763371421995661540622180222286491609840322732421598650475 +
0.42445293274705574412757500887055189552420282612221945972766975611605748380421821057087580584770905794678215958395810249645747226385011392829719555699234058808465069312539939557361013672581656837204405*I,
0.24505801487087417016068854563803448172521943510270968636805221995783706098457669244070126558322132754114006237893747704077409789994033154666761763371421995661540622180222286491609840322732421598650477 -
0.42445293274705574412757500887055189552420282612221945972766975611605748380421821057087580584770905794678215958395810249645747226385011392829719555699234058808465069312539939557361013672581656837204386*I ]
︡39e456d0-321b-4443-ac11-04aa49082ce1︡{"done":true}︡
︠0ce2711b-23ae-4ebf-bdd7-f744a4ab152fs︠
omega = prod([E.period_lattice(phi).basis(prec=1000)[0] for phi in K.embeddings(RR)])
︡f1ae97ba-383e-4a6c-b75d-3308498553c8︡{"done":true}︡
︠839c9cac-e015-4a79-ad39-10a77451f899s︠
c1 = l1*47*CC1(sqrt(5))/omega
c2 = l2*47.conjugate() *CC1(sqrt(5))/omega
︡673ce139-aae4-4e69-be10-db2a4434ea5f︡{"done":true}︡
︠94a36033-08ea-4591-8353-843544a2797es︠
c1,c2
︡46c3028e-2b10-4872-b216-c02d4fbc9adb︡{"stdout":"(0.9999999995653503062529576591124754896370504363434188055463447835913000245126430422276394574958995879729683943441266440810124106473200871203105837568300491479678574046284886618745443521709166986551736 + 1.732050807586195067941157851961213937336650671437163840656006336307774130379298105089823768284308618777381632838540174758579615723491693438187234643639901697333509474185442000836983390248527316165499*I, 0.9999999995653503062529576591124754896370504363434188055463447835913000245126430422276394574958995879729683943441266440810124106473200871203105837568300491479678574046284886618745443521709166986551737 - 1.732050807586195067941157851961213937336650671437163840656006336307774130379298105089823768284308618777381632838540174758579615723491693438187234643639901697333509474185442000836983390248527316165498*I)\n"}︡{"done":true}︡
︠cb38b857-eafe-451f-9784-7615efbc6d38s︠
x.conjugate()
︡4c18df1b-dda6-4740-a0b1-6449f290834e︡{"stdout":"11.3407561726636152699368162869855117983731253191903113812827727652124965276757522368493039894057371978570715000611418213033343214441382821742420971004022136131129716550720474800350052564067483123669351089814797540077428600188606608171977226854509076353420967694562397343116132495426591104271695619234 - 6.35509633539823757082843897576929635164123227418046373191723445222979581773290744537857331917542382091652147604151185486267441580032280296429497772415175454074114827575353571701097120106343964546518212091823462667259056273414807931764641831386718012747116711234367738464348211389670063607384427700001*I\n"}︡{"done":true}︡
︠58c3ef97-6f99-4295-a765-91444a9cd3d5ss︠
1/c1;1/c2;
︡e7cd5192-945a-4e79-bd57-b4cc7c727a75︡{"stdout":"0.4999999999999999999999999999999999999999999999999999999999999999999999999934956231565666574343088924407419896235212233272735000147214157716184640643318561169074097207246090575533634257256677689681113 - 9.789279086055920531037253731441653548566460090198335763674624714507240225895177402992985655384451524612420671959350614999606032086253312249764159225105263460065631461269354850272811495630508557477052e-75*I\n0.2610221927089224350365631712415115144995162664082569178958147777508118762544302932184219095265161745286366069433103338206566987549141885123237098148801496534879660519721023329528268952448575047226335 - 0.4264591597250857028365957388617469633260920057454412677493119493117616729542769917171234683549142379885358787137148975693919254844183663218964443829974242399178036667969166857387601436367253872148488*I\n"}︡{"done":true}︡
︠da421265-77de-4cba-8c9f-a57e5490f8a5s︠
c1, c2;
︡f8246689-604a-4b05-9cd8-30623b578c5d︡{"stdout":"(0.9999999995653503062529576591124754896370504363434188055463447835913000245126430422276394574958995879729683943441266440810124106473200871203105837568300491479678574046284886618745443521709166986551736 + 1.732050807586195067941157851961213937336650671437163840656006336307774130379298105089823768284308618777381632838540174758579615723491693438187234643639901697333509474185442000836983390248527316165499*I, 0.9999999995653503062529576591124754896370504363434188055463447835913000245126430422276394574958995879729683943441266440810124106473200871203105837568300491479678574046284886618745443521709166986551737 - 1.732050807586195067941157851961213937336650671437163840656006336307774130379298105089823768284308618777381632838540174758579615723491693438187234643639901697333509474185442000836983390248527316165498*I)\n"}︡{"done":true}︡
︠2c8658e5-d434-494c-aea3-5d92da259560s︠
c1*c2-4;c1+c2-2
︡c3f0ab3c-d7d1-4053-864f-f686bd95bcb4︡{"stdout":"-8.093088569877350958144983871293747909312945882759218380628346650543790566425014413834834802396732744152051493872087143862134447449917591500152645793415664931919724196162966488372064625571333503992959e-10 + 9.144941236411822604101211875669864313850200804989490725343365823468150650983299713086503530538041448730974292603275057833515443317510437438730834983953523435630821104602005456475703659443420968491774e-199*I\n-8.692993874940846817750490207258991273131623889073104328173999509747139155447210850082008240540632113117467118379751787053598257593788324863399017040642851907430226762509112956581666026896526704936875e-10 + 7.707879042118536194885307152350314207388026392776856468503694051208869834400209758172910118596349221073249760908474691602534445081901654412644560915046541181460263502450261741886664512959454816300209e-199*I\n"}︡{"done":true}
︠fae1912e-16b6-455f-9960-bc869894571bs︠
for d in range(1,13):
    algdep(c1,d,known_digits=10).factor()
︡fe98d804-002f-4976-8cfe-61a9111ee7fa︡{"stdout":"1\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\nx^2 - 2*x + 4\n"}︡{"done":true}︡
︠e3dde56a-300d-488e-9422-9b12525a0d61s︠
for d in range(1,13):
    algdep(c2,d,known_digits=60).factor()

︡4fcd6534-1f41-4b57-ac5d-2fc32826c1f0︡{"stdout":"x - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\nx - 2\n"}︡{"done":true}︡
︠1e153ffc-5366-4616-a53e-295ad1d05628s︠
R.<x> = QQ[]
K.<phi>=NumberField(x^2 -x-1)
E = EllipticCurve(K, [1, phi + 1, phi, phi, 0])
m = K*47
fact = [prime for (prime, i) in m.factor()]
d = 3
︡5e94f8a1-ac3b-47f5-ada2-7660cf93136c︡{"done":true}︡
︠984f2006-f6ff-4150-af52-83f9198f268bs︠
foundlist = len(fact)*[1]
for t in Integers(d)^len(m.factor()):
    try:
        if 0 in list(t):
            continue
        rootlist = list(t.lift())
        chi = NFChar(fact,rootlist,d)
        foundlist = rootlist

        print rootlist
        x = chi.gauss_sum();
        print
        print x.abs(),x
    except:
        pass
︡093a5a0b-bee4-4852-849b-a6bb781fba5d︡{"stdout":"[1]\n-2*phi + 1\n\n"}︡{"stdout":"47.0000000000000 47.0000000000000 + 1.30007116183606e-13*I\n[2]\n-2*phi + 1\n\n"}︡{"stdout":"46.9999999999999 46.9999999999999 + 3.00870439673417e-14*I\n"}︡{"done":true}︡
︠1165f539-1b36-4d87-942b-613cbf570c9c︠

︡70786a64-7cc6-47cb-b414-f7d604a5b4fa︡
︠e4176ba4-e16f-4f79-b363-697a0ec857c8︠
newchi = NFChar(fact, foundlist, d)
newchi(K.prime_above(2))
︡ed5c5234-a263-4348-b4fb-b2a5112edbb0︡{"stdout":"1.00000000000000\n"}︡{"done":true}︡
︠67e9b561-1f0c-4461-9c72-2c2992069359︠
x = newchi.gauss_sum();
print x.norm(),x
︡7203ea66-2a94-4ef0-94d8-c1cef3dd5b8d︡{"stdout":"169.000000000000 11.3407561726636 - 6.35509633539824*I\n"}︡{"done":true}︡
︠1e5bcc06-f6a3-4d85-b5d7-b017a645383d︠

︡d1f04e3d-3c62-4162-bd5c-e363ae7cae51︡
︠6a72e79d-3677-4fe1-8275-eeb7b77f4ad7︠
p = K.prime_above(2)
K = p.ring()
units = K.unit_group().gens()
x = p.gens_reduced()
print x
assert len(x)==1, "p not pricipally generated!"
x = x[0]
M = Matrix(GF(2),[[phi(g)<0 for phi in K.real_embeddings()] for g in units])
v = vector(GF(2),[phi(x)<0 for phi in K.real_embeddings()])
print v
x *= prod(g for g,e in zip(units,M.solve_left(v)) if e)
print x
assert x.is_totally_positive(), "Totally positive generator does not exist!"
︡0d0ddbd3-7fd7-4532-8d25-93794ddd369f︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/projects/sage/sage-7.5/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\nNameError: name 'K' is not defined\n"}︡{"done":true}︡
︠60441e86-17a7-421d-8694-2e2137ac0dc6︠
K
︡ae1a12e5-375d-461a-bf51-4d86bfe77d2c︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/projects/sage/sage-7.5/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\nNameError: name 'K' is not defined\n"}︡{"done":true}︡
︠30895934-91dc-4d44-ae1c-5073afb3c2df︠
M.solve_left(v)
︡b04f2e0d-2279-4e52-a06d-d42aef9d5893︡{"stdout":"(0, 1)\n"}︡{"done":true}︡
︠13acf71e-42fd-4cab-8d9c-519deeedeaa8︠
v;x
︡3160e184-68e3-418d-8eb3-26089a7ecec0︡{"stdout":"(1, 0)\n2*phi\n"}︡{"done":true}︡
︠2dd19d19-536f-41f9-8462-c6ce1fa037c5︠
totally_positive_generator??
︡eff2be41-d9ed-4d3a-bc22-68b25825d6a7︡{"code":{"filename":null,"lineno":-1,"mode":"python","source":"   File: /projects/68c8b2b8-03ba-44d4-a0d1-5d771c8cb465/code\nUnable to read source code (source code not available)"}}︡{"done":true}︡
︠338cdb12-fcb0-43b5-b146-75b0a5cba782︠
totally_positive_generator(K.prime_above(2))
︡dc4c13eb-afa4-470d-a209-f6a43c23baf2︡{"stdout":"2\n(0, 0)\n(0, 0)\n2\n"}︡{"done":true}︡
︠0c7fea60-52dc-460d-aa47-b840df289dd2︠

L = LSeriesEllipticCurve(E)
print "done1"
LEchi =  LSeriesTwist(L, newchi, epsilon='solve', conductor=ZZ(5^2*E.conductor().norm()*(newchi.conductor()^2)))
print E.conductor().norm()
print newchi.conductor()
LEchi
print "done2"
︡89fd4d34-9598-42c2-9b61-2a29a0a39bca︡{"stdout":"1.00000000000000\n"}︡{"stdout":"done1\n"}︡{"stdout":"31\n"}︡{"stdout":"169\n"}︡{"stdout":"Twist of L-series of Elliptic Curve defined by y^2 + x*y + phi*y = x^3 + (phi+1)*x^2 + phi*x over Number Field in phi with defining polynomial x^2 - x - 1 by <__builtin__.NFChar instance at 0x7fd03418dd40>\n"}︡{"stdout":"done2\n"}︡{"done":true}︡
︠ae8055d8-563d-4d41-b0cd-95a61c20a81e︠
LEchi.anlist(100)
L.conductor()
L.epsilon()
L.number_of_coefficients(2)
L.degree()
L.hodge_numbers()
L(3/2)
LEchi.number_of_coefficients(5)
LEchi.degree()
LEchi.hodge_numbers()
LEchi(ComplexField(5)(3/2))
︡c6b310f1-1612-462e-8467-2446304445f1︡{"stdout":"[0, 1, -0.000000000000000, -0.000000000000000, -3.00000000000000, 2.00000000000000, 0.000000000000000, -0.000000000000000, -0.000000000000000, 2.00000000000000, -0.000000000000000, 0.000000000000000, 0.000000000000000, 0, 0.000000000000000, -0.000000000000000, 5.00000000000000, 0, -0.000000000000000, 0.000000000000000, -6.00000000000000, 0.000000000000000, 0.000000000000000, 0, 0.000000000000000, -1.00000000000000, 0.000000000000000, -0.000000000000000, 0.000000000000000, -4.00000000000000, 0.000000000000000, -7.00000000000000, -0.000000000000000, 0.000000000000000, 0.000000000000000, -0.000000000000000, -6.00000000000000, 0, 0.000000000000000, 0.000000000000000, -0.000000000000000, 12.0000000000000, 0.000000000000000, 0, 0.000000000000000, 4.00000000000000, 0.000000000000000, 0, -0.000000000000000, 2.00000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, -8.00000000000000, 0.000000000000000, 4.00000000000000, 0.000000000000000, -0.000000000000000, -3.00000000000000, 0.000000000000000, 0.000000000000000, 0, 0.000000000000000, 0.000000000000000, 0.000000000000000, 8.00000000000000, -0.000000000000000, 0, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 16.0000000000000, 10.0000000000000, -5.00000000000000, -0.000000000000000, 0, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, -4.00000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0.000000000000000, 0, -0.000000000000000, 0.000000000000000, 3.00000000000000]"}︡{"stdout":"\n"}︡{"stdout":"775\n"}︡{"stdout":"1\n"}︡{"stdout":"534"}︡{"stdout":"\n"}︡{"stdout":"2\n"}︡{"stdout":"[0, 0, 1, 1]\n"}︡{"stdout":"0.607704196335035"}︡{"stdout":"\n"}︡{"stdout":"99729\n"}︡{"stdout":"2\n"}︡{"stdout":"[0, 0, 1, 1]\n"}︡{"done":true,"error":"killed"}︡
︠e56dbd1f-168c-41e8-80fe-db01503c7bb0︠
#better
def is_prime(n):
    """returns True if n is a prime false otherwise"""
    if n<2:
        return False
    
    for i in range(2,floor(sqrt(n))+1):
        if n%i == 0:
            return False
    
    return True

def primes_in_range(a,b):
    """returns the list of all primes in the range(a,b)"""
    return [i for i in range(a,b) if is_prime(i)]

print primes_in_range(2,20)
︡2acf1d4e-2652-4c73-b725-059f38fc78f1︡{"stdout":"[2, 3, 5, 7, 11, 13, 17, 19]\n"}︡{"done":true}︡
︠79de49fd-c20f-4fad-95e5-44356a8b56d2︠
L = LSeriesEllipticCurve(E)
import cProfile
t = cputime()
cProfile.runctx("L.anlist(100000)",None, locals(), filename="timing_data/profile_test", sort='cumulative')
print cputime(t)

︡5c12c587-8391-4fd6-a69a-b8760ddd5f0a︡{"stdout":"478.148\n"}︡{"done":true}︡{"stdout":"478.148\n"}︡{"done":true}
︠3d3b25bc-9f2d-4955-8401-fbbd932a1acb︠
LEchi =  LSeriesTwist(L, newchi, epsilon='solve', conductor=ZZ(5^2*E.conductor().norm()*(newchi.conductor()^2)))
t = cputime()
cProfile.runctx("LEchi.anlist(100000)",None, locals(), filename="timing_data/profile_test1", sort='cumulative')
print cputime(t)
︡394c3afb-90a9-4c1e-a0c8-0809f3212a54︡{"stdout":"26.52\n"}︡{"done":true}︡
︠c83dd2f6-d148-41a6-a453-c4eeb1162399o︠
print cputime(t)
︡869be7df-41b7-4711-99ba-45ec4be7611c︡{"stdout":"360.02\n"}︡{"done":true}︡
︠2e7c8d94-4c9f-4891-93ff-707891f3cb62o︠
L = LSeriesEllipticCurve(E)
L.anlist(100)
print "L done"
LEchi =  LSeriesTwist(L, newchi, epsilon='solve', conductor=ZZ(5^2*E.conductor().norm()*(newchi.conductor()^2)))
LEchi.anlist(100)
︡a75e33a8-aad9-4d0e-93cd-f1b64e043f08︡
︠3e5c1203-be9e-4430-bfdc-14e0297b200d︠
︡d2d56c5e-f31d-45ce-b4f8-b41f3498f6a2︡
︠25c2fc57-2413-409a-b0bf-b4de32707e20︠
%sh
python gprof2dot/gprof2dot.py -f pstats timing_data/profile_test | dot -Tpng -o timing_data/profile_LSeriesEllipticCurve_anlist100000_cachetest_opt.png 2> /dev/null
︡caf1df5e-291b-40fe-8dc3-7fd576b2c931︡{"done":true}︡
︠5f937d5e-d78c-489f-b5d9-9ef84f465d8c︠
%sh
python gprof2dot/gprof2dot.py -f pstats timing_data/profile_test1 | dot -Tpng -o timing_data/profile_LSeriesTwist_anlist100000_cachtest_opt.png 2> /dev/null
︡069999ff-e6e4-4dd7-87cd-8e3205f920f1︡{"done":true}︡
︠f531d951-8fa3-49e0-b283-763684694cea︠
L
︡a4af744b-d00f-4250-a52f-dc62b04927e8︡{"stdout":"L-series of Elliptic Curve defined by y^2 + x*y + phi*y = x^3 + (phi+1)*x^2 + phi*x over Number Field in phi with defining polynomial x^2 - x - 1\n"}︡{"done":true}︡
︠4440ef41-da8b-4b38-bc83-7e0cb27e6ddf︠

︠96c00861-087e-464f-b834-00be02de9d9f︠









